package
Version:
v1.10.0
Opens a new window with list of versions in this module.
Published: Jan 27, 2022
License: Apache-2.0
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Delete removes value from queue.
func GetByID(uid string) interface{}
GetByID returns element from Queue by uid.
func GetFirst() interface{}
GetFirst returns first element from Queue.
func GetLast() interface{}
GetLast returns last element from Queue.
IsInQueue checks is element with given uid in Queue.
func Put(uid string, data interface{})
Put adds value to queue.
Queue is a simple concurrency-safe FIFO implementation.
func NewQueue() (q *Queue)
NewQueue init empty Queue.
Delete removes value from queue.
GetByID returns element from Queue by uid.
func (q *Queue) GetFirst() interface{}
GetFirst returns first element from Queue.
func (q *Queue) GetLast() interface{}
GetLast returns last element from Queue.
IsInQueue checks is element with given uid in Queue.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.